| ReliaLearnR-package | R Documentation |
Learning modules for reliability analysis including modules for Reliability, Availability, and Maintainability (RAM) Analysis, Life Data Analysis, Reliability Testing, Repairable Systems Analysis, and Reliability Block Diagrams.
Maintainer: Paul Govan paul.govan2@gmail.com (ORCID) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.