| avail | R Documentation |
Availability is the proportion of time a system is in a functioning condition. This function computes availability given unavailable times and total times.
avail(unavailTime, totalTime)
unavailTime |
Numeric scalar or numeric vector of unavailable times. |
totalTime |
Numeric scalar or numeric vector of total times (same units as unavailTime). |
Numeric scalar: availability for the period (between 0 and 1).
avail(100, 1000)
avail(c(5,10), c(500,600))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.