| fr | R Documentation |
Failure rate is the frequency with which an engineered system or component fails, expressed in failures per unit of time. This function computes failure rate given failure counts and total operating times.
fr(failures, totalTime)
failures |
Numeric scalar or numeric vector of failure counts (non-negative). |
totalTime |
Numeric scalar or numeric vector of total operating times. |
Numeric scalar: failures per unit time (failures / totalTime).
fr(75, 5000)
fr(c(10,5), c(1000,2000))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.