| mttf | R Documentation |
For non-repairable items MTTF = total operating time / number of failures. The MTTF is the expected time to the first failure. It is commonly used for non-repairable items. The behavior implemented is the same as mtbf here; keep separate name for semantic clarity.
mttf(failures, totalTime)
failures |
Numeric scalar or numeric vector of failure counts (non-negative). |
totalTime |
Numeric scalar or numeric vector of total operating times. |
Numeric scalar: MTTF. If number of failures is zero, returns Inf (with a warning).
mttf(5, 1000)
mttf(c(2,3), c(500,500))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.