| rbd | R Documentation |
This function launches an interactive tutorial on Reliability Block Diagrams and system reliability, covering series, parallel, mixed, and k-out-of-n configurations as well as an introduction to Fault Tree Analysis.
rbd()
This function does not return a value.
https://paulgovan.github.io/ReliaLearnR/
if (interactive()) {
rbd()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.