| rel | R Documentation |
Reliability is the probability that an item will perform its intended function without failure over a specified period under stated conditions. This function computes reliability given outage times and total times.
rel(outageTime, totalTime)
outageTime |
Numeric scalar or numeric vector of forced outage times. |
totalTime |
Numeric scalar or numeric vector of total times (same units as outageTime). |
Numeric scalar: reliability for the period (between 0 and 1).
rel(100, 1000)
rel(c(10,20), c(500, 600))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.