| mtbf | R Documentation |
MTBF = total operating time / number of failures. The MTBF is the expected time between consecutive failures. It is commonly used for repairable items. The behavior is the same as mttf here; keep separate name for semantic clarity.
mtbf(failures, totalTime)
failures |
Numeric scalar or numeric vector of failure counts (non-negative). |
totalTime |
Numeric scalar or numeric vector of total operating times. |
Numeric scalar: MTBF. If number of failures is zero, returns Inf (with a warning).
mtbf(5, 1000)
mtbf(c(2,3), c(500,500))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.