This function launches an interactive tutorial on Reliability Block Diagrams and system reliability, covering series, parallel, mixed, and k-out-of-n configurations as well as an introduction to Fault Tree Analysis.
Examples
if (interactive()) {
rbd()
}